@@ -363,6 +363,12 @@ void XEMatrix::xMakePanther()
 			new int[ActiveConfiguration->Matrix.sizeMatrix*2];
 		ActiveConfiguration->Matrix.ZMatrix=
 			new int[ActiveConfiguration->Matrix.sizeMatrix*2];
+/*
+	timespec rem;
+	timespec FewTime;
+	FewTime.tv_sec=0;
+	FewTime.tv_nsec=1;
+*/
 
 		// loadin static matrix
 		// simulating the mouse movement from - infite to + infinite relative to 1 icon
@@ -404,6 +410,7 @@ void XEMatrix::xMakePanther()
 		}
 		for (int mouseinx=0;mouseinx<ActiveConfiguration->Matrix.sizeMatrix*2;mouseinx++)
 		{
+	//nanosleep(&FewTime,&rem);
 			int *vett=new int[ActiveConfiguration->Matrix.sizeMatrix*2];
 			for(int mouseiny=0;mouseiny<ActiveConfiguration->Matrix.sizeMatrix*2;mouseiny++)
 			{
@@ -456,6 +463,8 @@ void XEMatrix::xMakePanther()
 			/double(ActiveConfiguration->Matrix.sizeMatrix*2);
 		for (int mouseinx=0;mouseinx<ActiveConfiguration->Matrix.sizeMatrix*2;mouseinx++)
 		{
+	//nanosleep(&FewTime,&rem);
+
 			ActiveConfiguration->Matrix.KMatrix[mouseinx]=int(
 				ratiok*
 				double(ActiveConfiguration->Matrix.sizeMatrix*2-mouseinx));
