@@ -22,13 +22,19 @@
 
 #include <qobject.h>
 #include <qmutex.h>
-
-
-
 #include <stdlib.h>
 #include <unistd.h>
 #include <math.h>
+#include <qptrlist.h>
+#include <time.h>
+
 class XGIcon;
+class XSConfigurations;
+class XGDocker;
+class QTimer;
+class xGFloater;
+
+
 /**
 @author Stefano
 */
@@ -39,6 +45,7 @@ public:
     XEPlugin_Animator(QObject *parent = 0, const char *name = 0);
     ~XEPlugin_Animator();
 public slots:
+    void xAnimateDockerSlideRight(int,int,int,int,int,int,int,int);
     void xAnimateBounce(XGIcon *);
     void xAnimateMicro(XGIcon *);
     void xSetup();
@@ -61,17 +68,34 @@ public slots:
     void xGetInfo(QStringList &);
     void xStopAnimate();
     void xStartAnimate(XGIcon *);
-void xStartAnimate();
+    void xStartAnimate();
+    void xAnimateStepBounceDetached();
+    void xEventIconAdded(int);
+    void xAnimateStepFadeIcon();
+    void xAnimateFadeIcon(XGIcon *);
+    void xAnimateStepOverlay();
+    void xEventHighlightIcon(int,void *);
 protected:
-	class XSConfigurations *ActiveConfiguration;
-	class XGDocker	*xGDocker;
+	timespec	req,rem;
+
+	XSConfigurations *ActiveConfiguration;
+	XGDocker	*xGDocker;
+	double radians;
 	QPoint mouse;
 	QPoint mousef;
 	int moltiplier;
 	int lastRaise;
 	int animatorCounter;
+	int BounceHigh;
+	int	highlightAnimation;
 	//int Counter;
-	class XGIcon		*lastIcon;
+	XGIcon		*lastIcon;
+	QPtrList<XGIcon> lastIcons;
+	QTimer		*bounceTimer;
+	QTimer		*fadeTimer;
+	QTimer		*bounceDetachedTimer;
+	QTimer		*overlayPollTimer;
+	xGFloater *LocalDetachedWindow;
 	QMutex		AnimationsMutex;
 	
 	QString		onClickAnimation;
@@ -79,8 +103,17 @@ protected:
 	QString		onCloseAnimation;
 	QString		onHideAnimation;
 	QString		onShowAnimation;
+	QString		onAddAnimation;
+	QString		onSlideAnimation;
 
-	class XGIcon		*animatingIcon;
+	XGIcon		*animatingIcon;
+protected:
+    void xAnimateDockerSlideShow();
+    void xAnimateDockerFadeShow();
+    void xAnimateDockerFadeHide();
+    void xAnimateDockerSlideHide();
+protected:
+    void xAnimateOverlay(XGIcon *);
 };
 
 #endif
