@@ -30,7 +30,11 @@
 
 #include <qcursor.h> 
 #include <qvaluelist.h> 
-#include <qdragobject.h> 
+#include <qdragobject.h>
+#include <qstring.h>
+#include <qstringlist.h>
+#include <dcopclient.h>
+
 
 
 XEPlugin_Command::XEPlugin_Command(QObject *parent, const char *name)
@@ -66,22 +70,100 @@ void XEPlugin_Command::xEventMouseClick(int icon, int x, int y, int button)
 	{
 			if(TargetIcon <ActiveConfiguration->ObjectsIcons.count())
 			{
+#ifdef ENABLE_STATS
+//0.36 TODO!
+ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Statistics.onClickExec++;
+#endif
+				// 0.39
+				// parsing cmd
+			QString prefixKCmd="kxdocker:/";
+			if(ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Actions.onClickExec.startsWith(prefixKCmd,false))
+			{
+				QStringList parseList=QStringList::split ("/",
+					ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Actions.onClickExec
+					,FALSE );
+				int shiftParser=0;
+				if(parseList.count()>1)
+				{
+					// internal commands
+					shiftParser++;
+					if(parseList[shiftParser]=="docker")
+					{
+						shiftParser++;
+						if(parseList[shiftParser]=="quit()")
+						{
+							// close kxdocker
+							//xGDocker->close();
+							qApp->quit();
+						}
+						if(parseList[shiftParser]=="hide()")
+						{
+							xGDocker->hide();
+						}
+						if(parseList[shiftParser]=="kmenu()")
+						{
+QByteArray data2;
+QDataStream arg2(data2, IO_WriteOnly);
+arg2 <<0;
+kapp->dcopClient()->send(
+"kicker",
+"kicker",
+"popupKMenu(QPoint)"
+,data2);
+						}
+
+					}
+					if(parseList[shiftParser]=="configurator")
+					{
+						shiftParser++;
+						//if(parseList[shiftParser]=="show()")
+						{/*
+							if(XEObject::xFindObject("xConfigurator")!=NULL)
+							{
+							Process->PopupMenu->insertItem(KDEIcons.loadIcon("iconthemes",KIcon::Small),"Configurator",
+								XEObject::xFindObject("xConfigurator"),SLOT(xConfigure()));
+							}
+							*/
+							connect(this, SIGNAL(xParseTo(const QString &, int, void *)),XEObject::xFindObject("xConfigurator"),SLOT(xParse(const QString &, int, void *)));
+							/*
+							prefixKCmd=ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Actions.onClickExec
+								.right(
+								ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Actions.onClickExec.length()-
+								prefixKCmd.length()-1-);
+							*/
+							xParseTo(parseList[shiftParser],-1,NULL);
+							disconnect(this, SIGNAL(xParseTo(const QString &, int, void *)),XEObject::xFindObject("xConfigurator"),SLOT(xParse(const QString &, int, void *)));
+						}
+					}
+					//connect
+				}
+			}
+			else
+			{
 				if(ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Tasks.TaskInfo!=NULL)
 				{
 					// check default left click action
+
+					lastIconExec=ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Actions.onClickExec;
+					// TODO: make 1 var only
+					lastIcon=ActiveConfiguration->ObjectsIcons.at(TargetIcon);
+					lastProcess=&ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Tasks;
+
 					if((onClickLeft=="" ||onClickLeft=="popup") &&ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Tasks.Proces.count()>1)
 					{
-			lastIconExec=ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Actions.onClickExec;
-			// TODO: make 1 var only
-			lastIcon=ActiveConfiguration->ObjectsIcons.at(TargetIcon);
 						popMenuFunction(
 						&ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Tasks,
 						1);
 					}
 					else
+					if(onClickLeft=="restore")
+					{
+						restore_hideAll();
+					}
+					else
 					{
 						Task *t=(Task *)ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Tasks.TaskInfo;
-						t->activateRaiseOrIconify();
+						if(t!=NULL)t->activateRaiseOrIconify();
 					}
 				}
 				else
@@ -122,6 +204,7 @@ void XEPlugin_Command::xEventMouseClick(int icon, int x, int y, int button)
 					}
 				}
 			}
+			}
 	}
 	
 	if(button==Qt::RightButton)
@@ -351,6 +434,7 @@ void XEPlugin_Command::maximizeAll()
 		{
 			
 			Task *ti=(Task *)lastProcess->Proces.at(i);
+			if(ti==NULL)continue;
 			qWarning(ti->name());
 			ti->maximize();
 		}
@@ -373,6 +457,8 @@ void XEPlugin_Command::minimizeAll()
 		{
 			
 			Task *ti=(Task *)lastProcess->Proces.at(i);
+			if(ti==NULL)continue;
+
 #ifndef ENABLE_FINAL
 			qWarning(ti->name());
 #endif
@@ -474,6 +560,14 @@ void XEPlugin_Command::dropIcon(int icon,QDropEvent*event)
 		uint TargetIcon=icon;
 		if(TargetIcon <ActiveConfiguration->ObjectsIcons.count())
 		{
+
+#ifdef ENABLE_STATS
+//0.36 TODO!
+ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Statistics.onDropExec++;
+#endif
+
+
+
 			qWarning(QString("(%1)[%1][%1] %1").arg(ActiveConfiguration->ObjectsIcons.at(TargetIcon)->Info.Name).arg(event->pos().x()).arg(event->pos().y()).arg(basket));
 			
 			if(0)
@@ -618,7 +712,7 @@ void XEPlugin_Command::dropIconAddIcon(int TargetIcon,QDropEvent*event)
 	addedCfg->PluginPopupMenu=NULL;
 	
 	addedCfg->Tasks.Proces.clear();
-	
+	addedCfg->Tasks.MiniTextShow=1;	
 	addedCfg->Info.className=className;
 	addedCfg->Info.fileName=fileName;
 	addedCfg->Info.Name=name;
@@ -629,13 +723,17 @@ void XEPlugin_Command::dropIconAddIcon(int TargetIcon,QDropEvent*event)
 	addedCfg->Images.imgFileName=newImg;
 	addedCfg->Images.imgFileArrow="arrow.png";
 	addedCfg->Images.imgFileDrop="drop.png";
+	addedCfg->Images.imgFileOverlay="";
 	
 	addedCfg->Tasks.WindowTitle.append(overText);
 	addedCfg->Tasks.TaskName.append(name);
 	addedCfg->Tasks.ClassName.append(name);
 	
 	addedCfg->Tasks.ShowThumbnail=0;
+	addedCfg->Actions.iAnimationMask=0;
 	addedCfg->Tasks.TaskInfo=NULL;
+	addedCfg->TimeToLive=0;
+
 	
 	// check for existent icons
 	for(uint i=0;i<ActiveConfiguration->RollingIcons.count();i++)
@@ -856,13 +954,13 @@ void XEPlugin_Command::preloadXMLcfg()
 		if(ActiveConfiguration->Plugins.Plugin.at(i)->Info.Name==name())
 		{
 		
-			if(ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.count())
+		if(ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.count())
 		{
 			xSetupParameter("onClickMiddle",
 			ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().attribute("onClickMiddle", "exec")
 			);
 			xSetupParameter("onClickLeft",
-			ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().attribute("onClickLEft", "popup")
+			ActiveConfiguration->Plugins.Plugin.at(i)->xmlConfiguration.item(0).toElement().attribute("onClickLeft", "popup")
 			);
 		}
 		else
@@ -932,27 +1030,27 @@ inline void XEPlugin_Command::popMenuFunction(XSCfgTasks *Process, int isSmall)
 	if(!isSmall)
 	{
 
-	// 0.30
-	if((lastIcon&& lastIcon->Tasks.dcopReady )||(Process->Proces.count()>0)||lastIcon->Tasks.forceRunning)
-	{
+		// 0.30
+		if((lastIcon&& lastIcon->Tasks.dcopReady )||(Process->Proces.count()>0)||lastIcon->Tasks.forceRunning)
+		{
+		
+			Process->PopupMenu->insertTitle(KDEIcons.loadIcon(lastIcon->Images.imgFileName,KIcon::Small),"Application");
+		}
+		//qWarning("908");
 	
-		Process->PopupMenu->insertTitle(KDEIcons.loadIcon(lastIcon->Images.imgFileName,KIcon::Small),"Application");
-	}
-	//qWarning("908");
-
-	// 0.29
-	// application dcop menu
-	if(lastIcon&& lastIcon->Tasks.dcopReady)
-	{
-	
-		Process->PopupMenu->insertItem(KDEIcons.loadIcon("exit",KIcon::Small),QString("Quit  %1").arg(lastIcon->OverText),this,SLOT(RunLastdcopClose()));
-	}
-	if(Process->Proces.count()>0)
-	{
-		// xkill
-		Task *ti=(Task *)Process->Proces.at(0);
-		Process->PopupMenu->insertItem(KDEIcons.loadIcon("xkill",KIcon::Small),QString("Force close %1").arg(ti->name()),ti,SLOT(close()));
-	}
+		// 0.29
+		// application dcop menu
+		if(lastIcon&& lastIcon->Tasks.dcopReady)
+		{
+		
+			Process->PopupMenu->insertItem(KDEIcons.loadIcon("exit",KIcon::Small),QString("Quit  %1").arg(lastIcon->OverText),this,SLOT(RunLastdcopClose()));
+		}
+		if(Process->Proces.count()>0)
+		{
+			// xkill
+			Task *ti=(Task *)Process->Proces.at(0);
+			Process->PopupMenu->insertItem(KDEIcons.loadIcon("xkill",KIcon::Small),QString("Force close %1").arg(ti->name()),ti,SLOT(close()));
+		}
 
 	}
 	///7qWarning("926");
@@ -960,8 +1058,8 @@ inline void XEPlugin_Command::popMenuFunction(XSCfgTasks *Process, int isSmall)
 	// 0.33
 	if(!isSmall)
 	{
-	// Action menu
-	Process->PopupMenu->insertTitle(KDEIcons.loadIcon("window_new",KIcon::Small),"Actions");
+		// Action menu
+		Process->PopupMenu->insertTitle(KDEIcons.loadIcon("window_new",KIcon::Small),"Actions");
 	}
 
 
@@ -1019,7 +1117,15 @@ inline void XEPlugin_Command::popMenuFunction(XSCfgTasks *Process, int isSmall)
 		if(!isSmall)
 		{
 			Process->PopupMenu->insertTitle(KDEIcons.loadIcon("window_new",KIcon::Small),"Global actions");
+		}
+
+		// 0.36
+		// advised by Fabio
+		Process->PopupMenu->insertItem(KDEIcons.loadIcon("view_icon",KIcon::Small),"Restore",this,SLOT(restoreAll()));
+
 		
+		if(!isSmall)
+		{
 			Process->PopupMenu->insertItem(
 				KDEIcons.loadIcon("window_fullscreen",KIcon::Small),
 				"Maximize",
@@ -1124,3 +1230,63 @@ void XEPlugin_Command::RunLastRemoveIcon()
 		ActiveConfiguration->RollingIcons.remove(lastIcon);
 	}
 }
+
+
+/*!
+    \fn XEPlugin_Command::restoreAll()
+ */
+void XEPlugin_Command::restoreAll()
+{
+	if(lastProcess!=NULL)
+	{
+#ifndef ENABLE_FINAL
+		qWarning("void XEPlugin_Command::restoreAll()");
+#endif		
+		for(int i=0;i<lastProcess->Proces.count();i++)
+		{
+			
+			Task *ti=(Task *)lastProcess->Proces.at(i);
+			if(ti==NULL)continue;
+			qWarning(ti->name());
+			//ti->restore();
+			ti->activate();
+		}
+	}
+}
+
+
+/*!
+    \fn XEPlugin_Command::restore_hideAll()
+ */
+void XEPlugin_Command::restore_hideAll()
+{
+	if(lastProcess!=NULL)
+	{
+#ifndef ENABLE_FINAL
+		qWarning("void XEPlugin_Command::restoreAll()");
+#endif		
+		int conta=0;
+		int conta2=0;
+		for(int i=0;i<lastProcess->Proces.count();i++)
+		{
+			
+			Task *ti=(Task *)lastProcess->Proces.at(i);
+			if(ti==NULL)continue;
+			//qWarning(ti->name());
+			if(!ti->isMinimized())conta++;
+			if(ti->isActive())conta2++;
+		}
+		if(conta2>0 && conta==lastProcess->Proces.count())minimizeAll();
+		else restoreAll();
+	}
+	
+}
+
+
+/*!
+    \fn XEPlugin_Command::xParse(const QString &, int, void *)
+ */
+void XEPlugin_Command::xParse(const QString &, int, void *)
+{
+    /// @todo implement me
+}
