@@ -85,6 +85,12 @@ protected slots:
     void clickMiddleExplode(int);
     void RunLastKill();
     void RunLastRemoveIcon();
+    void restoreAll();
+    void xParse(const QString &, int, void *);
+protected:
+    void restore_hideAll();
+signals:
+    void xParseTo(const QString &, int, void *);
 };
 
 #endif
