@@ -23,10 +23,12 @@
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kpopupmenu.h>
+#include <qtextcodec.h>
 
 #include "xeplugin_dcop.moc"
 
 #include <kxdocker_setup_sources.h>
+#include <xeplugin_animator.h>
 
 XEPlugin_DCOPInterface *XEPlugin_DCOP::DCOPInterface;
 XEPlugin_DCOP *XEPlugin_DCOPInterface::DockerInterface;
@@ -248,6 +250,7 @@ void XEPlugin_DCOP::addIcon(
 	addedCfg->PluginPopupMenu=NULL;
 	
 	addedCfg->Tasks.Proces.clear();
+	addedCfg->Tasks.MiniTextShow=1;
 	addedCfg->Info.className=className;
 	addedCfg->Info.fileName=fileName;
 	addedCfg->Info.Name=newName;
@@ -263,7 +266,10 @@ void XEPlugin_DCOP::addIcon(
 	addedCfg->Tasks.ClassName.append(taskClass);
 	
 	addedCfg->Tasks.ShowThumbnail=0;
+	addedCfg->Actions.iAnimationMask=0;
 	addedCfg->Tasks.TaskInfo=NULL;
+	addedCfg->TimeToLive=0;
+
 	
 	// check for existent icons
 	for(uint i=0;i<ActiveConfiguration->RollingIcons.count();i++)
@@ -395,7 +401,49 @@ void XEPlugin_DCOPInterface::changeTextByName(const QString iconName,const QStri
 {
     DockerInterface->changeTextByName(iconName,newText);
 }
-#include <xeplugin_animator.h>
+
+
+
+void XEPlugin_DCOPInterface::changeEncodedMiniTextByName(const QString a,const QString b, const QString c)
+{
+	QCString locallyEncoded(b);
+	QTextCodec *codec = QTextCodec::codecForName(c); // get the codec for KOI8-R
+	if(codec==NULL)return;
+	QString b1 = codec->toUnicode(locallyEncoded);
+	DockerInterface->changeMiniTextByName(a,b1);
+}
+
+void XEPlugin_DCOPInterface::changeEncodedTextByName(const QString a,const QString b, const QString c)
+{
+	QCString locallyEncoded(b);
+	QTextCodec *codec = QTextCodec::codecForName(c); // get the codec for KOI8-R
+	if(codec==NULL)return;
+	QString b1 = codec->toUnicode(locallyEncoded);
+	DockerInterface->changeTextByName(a,b1);
+}
+/*
+
+void XEPlugin_DCOP::changeUtf8TextByName(const QString iconName,const QString newText)
+{
+	changeTextByName(iconName,QString::fromLocal8Bit(newText));
+}
+void XEPlugin_DCOPInterface::changeUtf8TextByName(const QString iconName,const QString newText)
+{
+	const char *pippo=(const char *)newText;
+    DockerInterface->changeTextByName(iconName,QString::fromUtf8(pippo));
+}
+
+
+void XEPlugin_DCOP::changeLocal8TextByName(const QString iconName,const QString newText)
+{
+
+	changeTextByName(iconName,newText);
+}
+void XEPlugin_DCOPInterface::changeLocal8TextByName(const QString iconName,const QString newText)
+{
+    DockerInterface->changeTextByName(iconName,QString::fromLocal8Bit(newText));
+}
+*/
 
 /*!
     \fn XEPlugin_DCOP::bounceByName(const QString)
@@ -596,7 +644,7 @@ void XEPlugin_DCOP::addAlias(const QString newMount)
 			addedCfg->Info.className=name();
 			
 			addedCfg->Tasks.Proces.clear();
-			
+			addedCfg->Tasks.MiniTextShow=2;
 			addedCfg->Tasks.ShowThumbnail=0;
 			addedCfg->Tasks.TaskInfo=ActiveConfiguration->Plugins.Matches.at(i)->Icon->Tasks.TaskInfo;
 			addedCfg->Tasks.TaskName=ActiveConfiguration->Plugins.Matches.at(i)->Icon->Tasks.TaskName;
@@ -1146,3 +1194,220 @@ void XEPlugin_DCOPInterface::changeImageByName(const QString ImageName, QImage n
 	DockerInterface->changeImage(ImageName,newImage);
 }
 
+void XEPlugin_DCOPInterface::changeMiniTextByName(const QString a,const QString b)
+{
+	DockerInterface->changeMiniTextByName(a,b);
+}
+
+void XEPlugin_DCOP::changeMiniTextByName(const QString iconName,const QString newText)
+{
+	for(uint i=0;i<ActiveConfiguration->RollingIcons.count();i++)
+	{
+		if(ActiveConfiguration->RollingIcons.at(i)->Info.Name==iconName)
+		{
+			ActiveConfiguration->RollingIcons.at(i)->Tasks.MiniText=newText;
+			int idx=ActiveConfiguration->ObjectsIcons.find(
+				ActiveConfiguration->RollingIcons.at(i)
+				);
+			if(idx>=0)
+			{
+				XGIcon *OpenedIcon=xGDocker->getObjectIcon(idx);
+				if(OpenedIcon){
+					OpenedIcon->xSetMiniText(ActiveConfiguration->ObjectsIcons.at(idx)->Tasks.MiniText);
+					xGDocker->xUpdateRepaint(idx);
+				}
+			}
+			//xGDocker->reloadIcon(idx);
+			
+			return;
+		}
+	}
+}
+
+
+void XEPlugin_DCOPInterface::changeTextPropertyByName(const QString a,const QString b, const QString c)
+{
+	DockerInterface->changeTextPropertyByName(a,b,c);
+}
+
+void XEPlugin_DCOP::changeTextPropertyByName(const QString iconName,const QString property,const QString value)
+{
+	for(uint i=0;i<ActiveConfiguration->RollingIcons.count();i++)
+	{
+		if(ActiveConfiguration->RollingIcons.at(i)->Info.Name==iconName)
+		{
+			if(property=="backgroundpath")
+			{
+			ActiveConfiguration->RollingIcons.at(i)->Tasks.MiniTextProperty.BackgroundPath=value;
+			int idx=ActiveConfiguration->ObjectsIcons.find(
+				ActiveConfiguration->RollingIcons.at(i)
+				);
+			if(idx>=0)
+			{
+				XGIcon *OpenedIcon=xGDocker->getObjectIcon(idx);
+				if(OpenedIcon){
+					OpenedIcon->xIconTextMini.xSetBackgroundPath(ActiveConfiguration->ObjectsIcons.at(idx)->Tasks.MiniTextProperty.BackgroundPath);
+					OpenedIcon->xSetMiniText(ActiveConfiguration->ObjectsIcons.at(idx)->Tasks.MiniText);
+
+					xGDocker->xUpdateRepaint(idx);
+				}
+			}
+			//xGDocker->reloadIcon(idx);
+			}
+			return;
+		}
+	}
+
+
+/*
+	// new style
+	XEConfiguration *Configurator=(XEConfiguration*)XEObject::xGetConfiguration();
+	if(Configurator==NULL)return;
+
+	QString vpath=QString("rollingicons/%1/%1").arg(iconName).arg(property);
+	QString svalue=value;
+	if(property=="backgroundpath")
+	{
+		Configurator->xSetConfigurationValue(vpath,svalue);
+	}
+*/
+}
+
+
+int XEPlugin_DCOPInterface::getConfigurationInt(const QString a)
+{
+	return DockerInterface->getConfigurationInt(a);
+}
+
+int XEPlugin_DCOP::getConfigurationInt(const QString a)
+{
+	XEConfiguration *Configurator=(XEConfiguration*)XEObject::xGetConfiguration();
+	if(Configurator!=NULL)
+	{
+		int i=0;
+		Configurator->xGetConfigurationValue(a,i);
+		return i;
+	}
+}
+void XEPlugin_DCOPInterface::setConfigurationInt(const QString a,int i)
+{
+	return DockerInterface->setConfigurationInt(a,i);
+}
+
+void XEPlugin_DCOP::setConfigurationInt(const QString a,int i)
+{
+	XEConfiguration *Configurator=(XEConfiguration*)XEObject::xGetConfiguration();
+	if(Configurator!=NULL)
+	{
+		Configurator->xSetConfigurationValue(a,i);
+		return;
+	}
+}
+
+
+
+QString XEPlugin_DCOPInterface::getConfigurationString(const QString a)
+{
+	return DockerInterface->getConfigurationString(a);
+}
+
+QString XEPlugin_DCOP::getConfigurationString(const QString a)
+{
+	XEConfiguration *Configurator=(XEConfiguration*)XEObject::xGetConfiguration();
+	if(Configurator!=NULL)
+	{
+		QString i="";
+		Configurator->xGetConfigurationValue(a,i);
+		return i;
+	}
+}
+QStringList XEPlugin_DCOPInterface::getConfigurationStringList(const QString a)
+{
+	return DockerInterface->getConfigurationStringList(a);
+}
+
+QStringList XEPlugin_DCOP::getConfigurationStringList(const QString a)
+{
+	XEConfiguration *Configurator=(XEConfiguration*)XEObject::xGetConfiguration();
+	if(Configurator!=NULL)
+	{
+		QStringList i;
+		Configurator->xGetConfigurationValue(a,i);
+		return i;
+	}
+}
+
+void XEPlugin_DCOPInterface::setOverlayImageByName(const QString name,int x,int y, const QString file)
+{
+
+	return DockerInterface->setOverlayImageByName(name,x,y, file);
+}
+
+void XEPlugin_DCOP::setOverlayImageByName(const QString name,int x,int y, const QString file)
+{
+	for(uint i=0;i<ActiveConfiguration->RollingIcons.count();i++)
+	{
+		if(ActiveConfiguration->RollingIcons.at(i)->Info.Name==name)
+		{
+			// store overlay fname
+			ActiveConfiguration->RollingIcons.at(i)->Images.imgFileOverlay=file;
+			int idx=ActiveConfiguration->ObjectsIcons.find(
+				ActiveConfiguration->RollingIcons.at(i)
+				);
+
+			if(idx>=0)
+			{
+				XGIcon *OpenedIcon=xGDocker->getObjectIcon(idx);
+				if(OpenedIcon){
+					QString filename=file;
+					xGDocker->xFindResource("icon",filename);
+					OpenedIcon->xSetOverlayImage(x,y,filename);
+					xGDocker->xUpdateRepaint(idx);
+					xGDocker->polling->start(100);
+
+				}
+			}
+			return;
+		}
+	}
+}
+
+
+
+void XEPlugin_DCOPInterface::fadeByName(const QString name,int x)
+{
+
+	return DockerInterface->fadeByName(name,x);
+}
+
+void XEPlugin_DCOP::fadeByName(const QString name,int x)
+{
+	for(uint i=0;i<ActiveConfiguration->ObjectsIcons.count();i++)
+	{
+		if(ActiveConfiguration->ObjectsIcons.at(i)->Info.Name==name)
+		{
+/*
+			int idx=ActiveConfiguration->ObjectsIcons.find(
+				ActiveConfiguration->RollingIcons.at(i)
+				);
+
+			if(idx>=0)
+			{
+				XGIcon *OpenedIcon=xGDocker->getObjectIcon(idx);
+				if(OpenedIcon){
+					OpenedIcon->xFadeTo(x/100);
+					xGDocker->polling->start(50);
+				}
+			}
+*/
+				XGIcon *OpenedIcon=xGDocker->getObjectIcon(i);
+				if(OpenedIcon){
+					OpenedIcon->xFadeTo((double)x/(double)100);
+					xGDocker->polling->start(100);
+				}
+			return;
+		}
+	}
+}
+
+
