@@ -61,6 +61,9 @@ public:
     void removeIcon(int index);
     void changeImageByName(const QString,const QString);
     void changeTextByName(const QString,const QString);
+    //void changeUtf8TextByName(const QString ,const QString);
+    //void changeLocal8TextByName(const QString ,const QString);
+    //void changeEncodedTextByName(const QString ,const QString, const QString);
     void bounceByName(const QString);
     void rollUpIcon(uint);
     void rollDownIcon(uint);
@@ -85,7 +88,14 @@ public:
     void changeImage(const QString, QPixmap);
     void changeImage(int, QImage);
     void changeImage(const QString, QImage);
-
+    void changeMiniTextByName(const QString,const QString);
+    void changeTextPropertyByName(const QString,const QString, const QString);
+    int getConfigurationInt(const QString);
+    QString getConfigurationString(const QString);
+    QStringList getConfigurationStringList(const QString);
+    void setOverlayImageByName(const QString ,int ,int , const QString);
+    void setConfigurationInt(const QString,int);
+    void fadeByName(const QString,int);
 public slots:
     void xSetup();
     void xStop();
@@ -135,13 +145,15 @@ class XEPlugin_DCOPInterface: public DCOPObject
 	const QString windowTitle,
 	const QString taskName,
 	const QString taskClass
-    
-    
     );
     void addAlias(const QString);
     void removeIcon(int index);
     void changeImageByName(const QString,const QString);
     void changeTextByName(const QString,const QString);
+    //void changeLocal8TextByName(const QString ,const QString);
+    //void changeUtf8TextByName(const QString ,const QString);
+    void changeEncodedTextByName(const QString ,const QString, const QString);
+    void changeEncodedMiniTextByName(const QString ,const QString, const QString);
     void bounceByName(const QString);
     void rollUpIcon(int);
     void rollDownIcon(int);
@@ -169,6 +181,14 @@ class XEPlugin_DCOPInterface: public DCOPObject
     void changeImageByName(const QString, QPixmap);
     void changeImage(int, QImage);
     void changeImageByName(const QString, QImage);
+    void changeMiniTextByName(const QString,const QString);
+    void changeTextPropertyByName(const QString,const QString, const QString);
+    int getConfigurationInt(const QString);
+    QString getConfigurationString(const QString);
+    QStringList getConfigurationStringList(const QString);
+    void setOverlayImageByName(const QString ,int ,int , const QString);
+    void setConfigurationInt(const QString,int);
+    void fadeByName(const QString,int);
 };
 
 #endif
