@@ -23,6 +23,7 @@
 #include <qwidget.h>
 
 #include <qpixmap.h>
+#include <qimage.h>
 
 #include <kwin.h>
 
@@ -46,6 +47,7 @@ public:
     void paintEvent( QPaintEvent *e);
     void setUnShadowed();
 protected:
+	class			QTimer *_timerHide;
 	QPixmap			paintBuffer;
 	KWin::WindowInfo	*info( WId win );
 	XSConfigurations 	*ActiveConfiguration;
@@ -53,6 +55,14 @@ protected:
 	QPixmap			pixmapBackground;
 	KRootPixmap		*KDesktopBackground;
 	int			NegativeX;
+	QRect rect;
+	int l;
+	int t;
+	int w;
+	int h;
+	double _alpha;
+	int lastX;
+	QImage _blendedText;
 public slots:
     void show();
     void xSetupParameter(const QString, const QString);
@@ -65,6 +75,7 @@ public slots:
     void backgroundUpdated(const QPixmap &);
     void xEventWidgetMoved(int,int,int , int , int,int);
     void hide();
+    void hideMe();
 };
 
 #endif
