@@ -40,11 +40,14 @@ protected:
 	class XGDocker	*xGDocker;
 	KDirWatch	*KDEWatch;
 	QString 	AutoAddMounts;
+	QString		onClickExec;
+	QString		prefixCaption;
+	QString 	ExternalEntryManager;
 public slots:
     void xSetup();
     void xStart();
     void xStop();
-    void MountAdded(const QString &);
+    void MountAdded(const QString &,const QString &,const QString &);
     void dirty(const QString &);
     void xGetParameter(const QString,QString&);
     void xGetParameterList(QStringList*);
