@@ -26,7 +26,8 @@
 #include "taskmanager.h"
 
 #include <stdlib.h>
-#include <unistd.h> 
+#include <unistd.h>
+#include <time.h>
 
 class DCOPClient;
 
@@ -51,8 +52,10 @@ protected:
 	int showGroupWindows;
 	int autoAddSeparator;
 	int thumbnailShowIcon;
-	int dcopPollingTimeout;
+//	int dcopPollingTimeout;
 	DCOPClient    * dcopClient;
+	timespec	req,rem;
+	QString		activeOverlay;
 
 public slots:
     void xSetup();
@@ -88,6 +91,10 @@ protected:
 protected:
     void taskActivatedMultipass(Task *t);
     void taskActivatedCheckTitle(Task *t);
+protected:
+    void xUpdateMiniText(int);
+protected:
+    void dockAppAdded(class XGIcon *,Task *);
 };
 
 #endif
