@@ -82,3 +82,42 @@ void XERoot::xStop()
 	//qWarning("void XERoot::xStop()");
 	xPluginStop();
 }
+
+
+/*!
+    \fn XERoot::xStart(const QString&)
+ */
+void XERoot::xStartThis(const QString&sPName)
+{
+	QObject *pObject=XEObject::xFindObject(sPName);
+	if(!pObject)return;
+	connect(this,SIGNAL(xThisPluginStart()),pObject, SLOT(xStart()));
+	xThisPluginStart();
+	disconnect(SIGNAL(xThisPluginStart()));
+}
+
+
+/*!
+    \fn XERoot::xSetup(const QString &)
+ */
+void XERoot::xSetupThis(const QString &sPName)
+{
+	QObject *pObject=XEObject::xFindObject(sPName);
+	if(!pObject)return;
+	connect(this,SIGNAL(xThisPluginSetup()),pObject, SLOT(xSetup()));
+	xThisPluginSetup();
+	disconnect(SIGNAL(xThisPluginSetup()));
+}
+
+
+/*!
+    \fn XERoot::xStop(const QString &)
+ */
+void XERoot::xStopThis(const QString &sPName)
+{
+	QObject *pObject=XEObject::xFindObject(sPName);
+	if(!pObject)return;
+	connect(this,SIGNAL(xThisPluginStop()),pObject, SLOT(xStop()));
+	xThisPluginStop();
+	disconnect(SIGNAL(xThisPluginStop()));
+}
