@@ -38,10 +38,16 @@ public slots:
     void xSetup();
     void xStart();
     void xStop();
+    void xStartThis(const QString&);
+    void xSetupThis(const QString &);
+    void xStopThis(const QString &);
 signals:
     void xPluginSetup();
     void xPluginStart();
     void xPluginStop();
+    void xThisPluginSetup();
+    void xThisPluginStart();
+    void xThisPluginStop();
 };
 
 #endif
